function [meanFilter, gaussianFilter, minFilter, maxFilter] = curveFilter(image, sigma)
    % curveFilter : Calculates the curvatures of an image
    %
    % INPUT : 
    %       image : Image to be filtered
    %       sigma : Sigma of smoothing gaussian. Defines the space-scale of
    %       the filter.
    % OUTPUT : 
    %       mean : Mean curvature of the image
    %       gaussian : Gaussian curvature of the image
    %       min : Minimum principal curvature of the image
    %       max : Maximum principal curvature of the image
    %
    % Copyright (C) 2016 Wiggins Lab
    % University of Washington, 2016

    % Make filter 
    x = -10:10;
    [meshX, meshY] = meshgrid( x, x);
    radius = meshX.^2 + meshY.^2;

    % Initialize sigma
    if ~exist( 'sigma', 'var' ) || isempty( sigma )
        sigma = 1.5;
    end
    
    % Make sure image is in double format
    image = double(image);

    sigmaSquared = sigma^2;

    %Calculate filter kernals for each of the Hessian elements (Second
    %derivatives of gaussian kernal)
    gaussianKernal = 1/(2 * pi * sigmaSquared) * exp(-radius/(2 * sigmaSquared));
    hessianXX = (2 * pi * sigmaSquared^2) * ((meshX / sigmaSquared).^2 - 1/sigmaSquared) .* gaussianKernal;
    hessianYY = (2 * pi * sigmaSquared^2) * ((meshY / sigmaSquared).^2 - 1/sigmaSquared) .* gaussianKernal;
    hessianXY = (2 * pi * sigmaSquared^2) * meshX .* meshY .* gaussianKernal/sigmaSquared^2;

    % Do filtering
    imageXX = imfilter( image, hessianXX, 'replicate' );
    imageYY = imfilter( image, hessianYY, 'replicate' );
    imageXY = imfilter( image, hessianXY, 'replicate' );

    % Gaussian curvature
    gaussianFilter = imageXX .* imageYY - imageXY.^2;

    % Mean curvature
    meanFilter = -(imageXX + imageYY)/2;

    % Min and max principal curvatures
    minFilter = (meanFilter - sqrt(abs(meanFilter.^2 - gaussianFilter)));
    maxFilter = (meanFilter + sqrt(abs(meanFilter.^2 - gaussianFilter)));
end