function [putativeFociData] = findFoci(image, sigma)
    % findFoci : returns a list of putative foci in image with a score and
    %   position
    %
    % INPUT :
    %       im : Image to be filtered
    %       sigma : Sigma of smoothing gaussian. Defines the space-scale of
    %       the filter.
    % OUTPUT :
    %       putativeFociData : List of putative foci found
    %           x : X position of foci (To the nearest pixel)
    %           y : Y position of foci (To the nearest pixel)
    %           score : Value of the intensity of the foci. Use this score to
    %               define a cutoff point to distinguish true putative foci from
    %               false putative foci
    %
    % NOTE : The algorithm can be further improved if the filtered foci are
    %   fit to sub pixel resolution with a gaussian fitting routine.
    %   (Not implimented)
    %
    % Copyright (C) 2016 Wiggins Lab
    % University of Washington, 2016

    % Filter and watershed image to collect regions of local maxima
    filteredImage = minFilter(image, sigma);
    regions =  bwlabel(watershed(-filteredImage));

    % Get region information
    regionData = regionprops( regions, filteredImage, {'PixelValues', 'PixelIdxList'} );

    numRegions = max( regions(:) );

    % Initialize output array
    propertiesInit.score = nan;
    propertiesInit.x = nan;
    propertiesInit.y = nan;

    putativeFociData(numRegions) = propertiesInit;

    imageSize = size( image );

    % Construct output array from region data
    for i = 1:numRegions
        [putativeFociData(i).score, index] = max( regionData(i).PixelValues );

        [putativeFociData(i).y, putativeFociData(i).x] = ind2sub(imageSize, regionData(i).PixelIdxList(index));
    end

end